@@ -16,6 +16,7 @@ ci_loader_conf = {
             ],
         },
         "tag": "BITBUCKET_TAG",
+        "source_type": None,
     },
     "github": {
         # REF https://docs.github.com/en/actions/learn-github-actions/environment-variables
@@ -31,10 +32,12 @@ ci_loader_conf = {
             ],
         },
         "tag": "GITHUB_REF_NAME",
+        "source_type": "GITHUB_REF_TYPE",  # Github-only feature
     },
     "gitlab": {
         # REF https://docs.gitlab.com/ee/ci/variables/predefined_variables.html
         "commit": "CI_COMMIT_SHA",
+        "commit_message": "CI_COMMIT_MESSAGE",
         "branch": "CI_COMMIT_REF_NAME",
         "pipeline_id": "CI_PIPELINE_ID",
         "job_url": {
@@ -44,6 +47,7 @@ ci_loader_conf = {
             ],
         },
         "tag": "CI_COMMIT_TAG",
+        "source_type": None,
     },
     "azure": {
         "commit": "BUILD_SOURCEVERSION",
@@ -60,8 +64,11 @@ ci_loader_conf = {
             ],
         },
         "tag": "BUILD_SOURCEBRANCHNAME",
+        "source_type": None,
     },
 }
+
+
 # this is a required function signature so there are going to be unused arguments
 # pylint: disable=unused-argument
 def load(obj, env=None, silent=True, key=None, filename=None):
@@ -84,12 +91,30 @@ def load(obj, env=None, silent=True, key=None, filename=None):
         if not ci_provider_env_cfg["commit"] in environ:
             continue
 
+        if (
+            ci_provider_env_cfg["source_type"]
+            and ci_provider_env_cfg["source_type"] in environ
+        ):
+            ci_config_dict["source_type"] = environ.get(
+                ci_provider_env_cfg["source_type"]
+            )
+        else:
+            ci_config_dict["source_type"] = (
+                "branch" if environ.get(ci_provider_env_cfg["tag"]) is None else "tag"
+            )
+
         ci_config_dict["provider"] = ci_provider
         ci_config_dict["commit"] = environ.get(ci_provider_env_cfg["commit"])
         ci_config_dict["branch"] = environ.get(ci_provider_env_cfg["branch"])
         ci_config_dict["pipeline_id"] = environ.get(ci_provider_env_cfg["pipeline_id"])
         ci_config_dict["tag"] = environ.get(ci_provider_env_cfg["tag"])
 
+        # Attempt to get commit message
+        if "commit_message" in ci_provider_env_cfg:
+            ci_config_dict["commit_message"] = environ.get(
+                ci_provider_env_cfg["commit_message"]
+            )
+
         job_url_cnf = ci_provider_env_cfg["job_url"]
         ci_config_dict["job_url"] = job_url_cnf["format"].format(
             *[environ[env_var] for env_var in job_url_cnf["variables"]]
