@@ -14,10 +14,12 @@ from datetime import datetime
 from operator import itemgetter
 from urllib.parse import urlparse
 import platform
+import json
+from requests.exceptions import SSLError
 from dynaconf.vendor.toml.decoder import TomlDecodeError
 from dynaconf import Dynaconf
 from dynaconf.loaders import toml_loader
-import requests
+import certifi
 import dotenv
 import click
 import boto3
@@ -25,6 +27,7 @@ from embedops_cli.api.configuration import Configuration
 from embedops_cli.api.rest import ApiException
 from embedops_cli.api.api_client import ApiClient
 from embedops_cli.eo_types import (
+    EMBEDOPS_REGISTRY,
     DockerRegistryException,
     LoginFailureException,
     UnauthorizedUserException,
@@ -33,14 +36,14 @@ from embedops_cli.eo_types import (
     BadTomlFileException,
     UserDeclinedException,
     LoginTimeoutException,
+    SSLException,
 )
 from embedops_cli.api.api.default_api import DefaultApi
 from embedops_cli.config import settings
-from embedops_cli.utilities import echo_error_and_fix
+from embedops_cli.utilities import echo_error_and_fix, requests
 
 _logger = logging.getLogger(__name__)
 
-EMBEDOPS_REGISTRY = "https://registry.embedops.com"
 user_secrets = os.path.join(os.path.expanduser("~"), ".eosecrets.toml")
 
 
@@ -206,9 +209,12 @@ def request_user_code(client_id, base_url):
 
     url = f"{base_url}/device/code"
 
-    code_req_response = requests.post(
-        url, data=data, timeout=int(settings.get("http_timeout", 60))
-    )
+    try:
+        code_req_response = requests.post(
+            url, data=data, timeout=int(settings.get("http_timeout", 60))
+        )
+    except SSLError:
+        echo_error_and_fix(SSLException())  # exits
     return code_req_response.json()
 
 
@@ -321,6 +327,7 @@ def docker_cli_login(aws_access_key_id, aws_secret_access_key):
         "sts",
         aws_access_key_id=aws_access_key_id,
         aws_secret_access_key=aws_secret_access_key,
+        verify=certifi.where(),
     )
     # need to assume proper role before being able to grab ECR credentials
     assume_role_response = sts_client.assume_role(
@@ -336,6 +343,7 @@ def docker_cli_login(aws_access_key_id, aws_secret_access_key):
         aws_secret_access_key=aws_secret_access_key,
         aws_session_token=aws_session_token,
         region_name="us-west-2",
+        verify=certifi.where(),
     )
 
     ecr_authorization_data = ecr_client.get_authorization_token()["authorizationData"][
@@ -348,18 +356,19 @@ def docker_cli_login(aws_access_key_id, aws_secret_access_key):
         "authorizationToken", "proxyEndpoint"
     )(ecr_authorization_data)
     registry_token = base64.b64decode(authorization_token).decode().replace("AWS:", "")
+    login_command = f"echo {registry_token} | \
+        docker login -u AWS --password-stdin {urlparse(registry_server).netloc}"
+    if platform.system() == "Windows":
+        login_command = "powershell " + login_command
+    _logger.debug("EO Registry login command: %s", login_command)
     try:
-        subprocess.check_output(
-            ("powershell " if platform.system() == "Windows" else "")
-            + f"echo {registry_token} | \
-                docker login -u AWS --password-stdin {urlparse(registry_server).netloc}",
-            shell=True,
-            stderr=subprocess.DEVNULL,
+        subprocess.run(
+            login_command, check=True, shell=True, capture_output=True, text=True
         )
         return 0
     except subprocess.CalledProcessError as err:
-        _logger.error(err.returncode)
-
+        _logger.error(f"Registry login exit code: {err.returncode}")
+        _logger.error(f"Registry login error: {err.stderr.strip()}")
         return err.returncode
 
 
@@ -383,6 +392,23 @@ def login_to_registry(secrets_file=user_secrets):
     return return_code
 
 
+def docker_cli_logout():
+
+    """
+    Logout from the docker registry.
+    """
+
+    try:
+        subprocess.check_output(
+            ("powershell " if platform.system() == "Windows" else "")
+            + f"docker logout {EMBEDOPS_REGISTRY}",
+            shell=True,
+            stderr=subprocess.DEVNULL,
+        )
+    except subprocess.CalledProcessError as err:
+        _logger.error(err.returncode)
+
+
 def is_registery_token_valid(secrets_file=user_secrets):
     """Check if register token has expired"""
     registry_token_expires_at = get_docker_expiration_time(secrets_file)
@@ -399,3 +425,34 @@ def is_registery_token_valid(secrets_file=user_secrets):
     )
 
     return is_valid
+
+
+def check_registry_login():
+    """Check if logged in to the registry"""
+    logged_in = None
+    docker_config_path = os.path.join(os.path.expanduser("~"), ".docker", "config.json")
+    try:
+        with open(docker_config_path, "r", encoding="utf-8") as file:
+            config = json.load(file)
+            logged_in = EMBEDOPS_REGISTRY in config.get("auths", {})
+    except FileNotFoundError:
+        logged_in = False
+    ## TODO: refactor to avoid circular dependency for the next line.
+    ## Running `login`` on previously logged in registry will reuse
+    ## existing credentials to reauthenticate if necessary or fail
+    ## if no longer valid.
+    ## This accounts for scenario where password store is no longer valid
+    ## but Docker still has registry in its config file.
+    # docker_cli_run(["login", EMBEDOPS_REGISTRY])
+    _logger.debug(f"Logged into registry {EMBEDOPS_REGISTRY}: {logged_in}")
+    return logged_in
+
+
+def delete_secrets_file(secrets_file=user_secrets):
+
+    """
+    Delete the user secrets file.
+    """
+
+    if os.path.isfile(secrets_file):
+        os.remove(secrets_file)
