@@ -25,8 +25,11 @@ from embedops_cli.embedops_cli_internal import (
     _say_available_ci_jobs,
     _get_job_name_list,
     _say_token_is_good,
+    _handle_network_exception,
 )
+from embedops_cli.api.rest import ApiException
 from embedops_cli.hil.hil_commands import get_repo_fleet_devices
+from embedops_cli.embedops_cli_plugins import ToolsGroupCommand
 
 # import embedops_cli.yaml_tools.yaml_utilities as yaml_utilities
 from embedops_cli.yaml_tools import yaml_utilities
@@ -52,6 +55,9 @@ _logger = logging.getLogger(__name__)
 
 CONTEXT_SETTINGS = {"help_option_names": ["-h", "--help", "--halp"]}
 
+# Commands that skip token validation
+SKIP_TOKEN_COMMANDS = ["logout", "tools"]
+
 
 # User specified context for subcommands
 class Config:
@@ -85,6 +91,10 @@ def embedops_cli(ctx: click.Context, debug, test):
     if ctx.invoked_subcommand is None:
         _embedops_cli_help(ctx)
 
+    if ctx.invoked_subcommand in SKIP_TOKEN_COMMANDS:
+        # On logout, don't do any token checking or processing
+        return
+
     # if command needs embedops token check it
     # TODO: only get embedops token if needed for subcommand
     token = _get_and_check_embedops_token(test)
@@ -146,6 +156,20 @@ def login(ctx: click.Context):
     telemetry.login_event()
 
 
+@embedops_cli.command()
+def logout():
+
+    """
+    Perform logout operation. This deletes user secrets and logs out from Docker.
+    """
+
+    telemetry.logout_event()
+    embedops_authorization.delete_secrets_file()
+    embedops_authorization.docker_cli_logout()
+
+    click.secho("You are logged out from EmbedOps!\n", err=False, fg="white")
+
+
 def print_command_info(ctx: click.Context, opts: click.STRING):
     """Helper function that echoes formatted CLI equivalent commands
     when user uses the wizard functionality."""
@@ -282,16 +306,17 @@ def run(ctx: click.Context, job_name, docker_cache=False, terminal=False):
         current_time = datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S UTC")
         click.secho("-" * 80, fg="magenta")
         click.secho(f"Running job   '{job_name}'", err=False, fg="magenta")
-        click.secho(f"-> repo id    '{repo_id}'", err=False, fg="white")
-        click.secho(f"-> file       '{filename}'", err=False, fg="white")
-        click.secho(f"-> directory  '{os.getcwd()}'", err=False, fg="white")
+        click.secho(f"-> cli version   '{version.__version__}'", err=False, fg="white")
+        click.secho(f"-> repo id       '{repo_id}'", err=False, fg="white")
+        click.secho(f"-> file          '{filename}'", err=False, fg="white")
+        click.secho(f"-> directory     '{os.getcwd()}'", err=False, fg="white")
         click.secho(
-            f"-> image      '{job.docker_tag if job.docker_tag else 'N/A'}'",
+            f"-> image         '{job.docker_tag if job.docker_tag else 'N/A'}'",
             err=False,
             fg="white",
         )
-        click.secho(f"-> git sha    '{git_hash}'", err=False, fg="white")
-        click.secho(f"-> timestamp  '{current_time}'", err=False, fg="white")
+        click.secho(f"-> git sha       '{git_hash}'", err=False, fg="white")
+        click.secho(f"-> timestamp     '{current_time}'", err=False, fg="white")
         click.secho("-" * 80, fg="magenta")
         click.secho("\n")
         try:
@@ -403,6 +428,7 @@ def describe(ctx: click.Context, job_name):
 )
 @click.pass_context
 def hil(ctx: click.Context, devices):
+    # pylint: disable=too-many-branches
     """Group for all hil commands.
 
 
@@ -420,7 +446,7 @@ def hil(ctx: click.Context, devices):
     ctx.obj["devices"] = devices
 
     if not ctx.invoked_subcommand:
-        repo_fleet_devices = get_repo_fleet_devices()
+
         click.secho("--- user controls " + "-" * 62, fg="magenta")
         click.secho("\t   navigation    : arrow keys (← → ↑ ↓)", fg="white")
         click.secho("\t   select        : enter key  (↵)", fg="white")
@@ -451,6 +477,11 @@ def hil(ctx: click.Context, devices):
             # invoke fleet command
             ctx.invoke(getattr(hil_commands, action))
         else:
+            try:
+                repo_fleet_devices = get_repo_fleet_devices()
+            except ApiException as exc:
+                _handle_network_exception(exc)
+                sys.exit(0)
             if len(repo_fleet_devices) >= 1:
                 choices = [
                     Choice(
@@ -493,6 +524,11 @@ hil.add_command(hil_commands.fleet)
 hil.add_command(hil_commands.provision)
 
 
+@embedops_cli.group(cls=ToolsGroupCommand)
+def tools():
+    """Top-level group for tools command (supports plugins)"""
+
+
 if __name__ == "__main__":
     # Top level catch block in case there are known exception that make it to this level
     try:
