@@ -24,6 +24,8 @@ SUPPORTED_CI_FILENAMES = [
     GH_CI_CONFIG_FILENAME,
 ]
 
+EMBEDOPS_REGISTRY = "623731379476.dkr.ecr.us-west-2.amazonaws.com"
+
 
 class YamlType(Enum):
     """Types of Yaml Files EmbedOps Tools supports"""
@@ -151,9 +153,11 @@ class NoYamlFileException(EmbedOpsException):
 
     ERROR_MSG = f"CI configuration YAML file could not be found in {getcwd()}\n"
     ERROR_FIX = (
-        "Either specify a filename with the --filename option or make sure\n"
-        "one of the following CI configuration files is in the current directory:\n"
-        "    " + "\n    ".join(SUPPORTED_CI_FILENAMES) + "\n"
+        "Make sure you are at the root of a repository that is configured w/ EmbedOps\n"
+        "and that one of the following CI configuration files is in the current directory:\n"
+        "    " + "\n    ".join(SUPPORTED_CI_FILENAMES) + "\n\n"
+        "If the CI configuration file of interest does not match any of the above,\n"
+        "specify the filename with the --filename option"
     )
 
     def __init__(
@@ -460,18 +464,28 @@ class DockerNotRunningException(EmbedOpsException):
 class DockerRegistryException(EmbedOpsException):
     """Raised when a problem accessing the registry is encountered"""
 
-    ERROR_MSG = (
-        "We were unable to authenticate with the package registry, "
-        "or the image name is not correct.\n"
-    )
+    ERROR_MSG = "We were unable to authenticate with the container registry\n"
     ERROR_FIX = (
-        "To access the required Docker images needed run this job,\n"
-        "login to the EmbedOps Docker registry using this command:\n"
-        "\n"
-        "    docker login registry.embedops.com\n"
-        "\n"
-        "When prompted, login with your access token, found on app.embedops.io\n"
-        "Check in registry that the image name exists."
+        "Use error logs above, if present, to determine cause of failure.\n"
+        "If using Docker Desktop for Linux, make sure password store 'pass' is initialized\n"
+        "(https://docs.docker.com/desktop/get-started/#signing-in-with-docker-desktop-for-linux)\n"
+    )
+
+    def __init__(
+        self,
+        message=ERROR_MSG,
+        fix_message=ERROR_FIX,
+    ):
+        super().__init__(message, fix_message)
+
+
+class DockerImageNotFoundException(EmbedOpsException):
+    """Raised when image specified is not found"""
+
+    ERROR_MSG = "Incorrect image name\n"
+    ERROR_FIX = (
+        "Check and make sure the the image specified\n"
+        "for the job in the CI YAML is correct\n"
     )
 
     def __init__(
@@ -551,10 +565,11 @@ class SshDirIsNotADirectoryException(EmbedOpsException):
 class NoRepoIdException(EmbedOpsException):
     """Raised when the repo id could not be found"""
 
-    ERROR_MSG = "repo id not found\n"
+    ERROR_MSG = f"Project's repo id not found in {getcwd()}\n"
     ERROR_FIX = (
-        "This command requires a valid repo ID file in the project root.\n"
-        "Reconnect your repository or change directories to a valid EmbedOps project."
+        "This command requires a valid repo ID file (.embedops/repo_id.yml)\n"
+        "in the current working directory. Make sure you are the root of a\n"
+        "repository that is configured w/ EmbedOps."
     )
 
     def __init__(
