@@ -5,8 +5,12 @@ Utility for telemetry
 * Author(s): Jimmy Gomez
 """
 import logging
-import requests
+from requests import (
+    ConnectionError as RequestsConnectionError,
+    Timeout as RequestsTimeout,
+)
 from embedops_cli.config import settings
+from .utilities import requests
 from .embedops_authorization import get_auth_token
 
 
@@ -22,6 +26,12 @@ def login_event():
     send_telemetry(event)
 
 
+def logout_event():
+    """Logout Event"""
+    event = {"name": "logout"}
+    send_telemetry(event)
+
+
 def command_event(command, subcommands):
     """Format CLI command event for telemetry and send"""
     event = {"name": command, "params": subcommands}
@@ -37,7 +47,7 @@ def send_telemetry(event):
 
     try:
         requests.post(url, headers=headers, json=event, timeout=5.0)
-    except requests.ConnectionError as exc:
+    except RequestsConnectionError as exc:
         _logger.debug(f"telemetry connection error: {exc}")
-    except requests.Timeout as exc:
+    except RequestsTimeout as exc:
         _logger.debug(f"telemetry timeout error: {exc}")
