@@ -10,7 +10,8 @@ import platform
 import logging
 import sys
 import click
-import requests
+import requests as requests_module
+import certifi
 from embedops_cli.eo_types import EmbedOpsException
 from embedops_cli.config import settings
 from embedops_cli.api.api_client import ApiClient
@@ -24,6 +25,22 @@ compiler_image_regex = re_compile(
     r"(?P<compiler>[^\/\:]+)(?:\:(?P<image_version>[^\/]+))?\/?$"
 )
 
+# persistent client session to be used throughout the project
+requests = requests_module.Session()
+
+"""
+The following avoids possible SSL verification errors with domains that CLI makes request against.
+Some users have Root certificates that do not include the necessary certificates for SSL
+    verification to work.
+This fix does the following:
+- Makes a HEAD request to the domains of interest. This minimizes payload and request time
+- Forces the use of the Root certificate packaged with certifi
+- After successful request, the Session persists the successful verification,
+    so there is no need to specify certifi's Root Certicate for future requests
+"""
+requests.head(f"{settings.host}", verify=certifi.where())
+requests.head(f"{settings.base_url}", verify=certifi.where())
+
 
 def logging_setup(logger_name, level=None):
     """helper function for supporting EMBEDOPS_DEBUG_LEVEL
@@ -103,7 +120,7 @@ def post_dict(
 ):
     """POSTs the given object to the given URL as JSON"""
 
-    req = requests.Request(
+    req = requests_module.Request(
         "POST",
         endpoint_uri,
         headers=headers,
@@ -112,9 +129,9 @@ def post_dict(
         data=data_dict,
     )
     prepared = req.prepare()
-    session = requests.Session()
+    session = requests_module.Session()
 
-    return session.send(prepared)
+    return session.send(prepared, verify=certifi.where())
 
 
 def quote_str_for_platform(str_to_quote):
