@@ -185,9 +185,28 @@ def subprocess_err_code(errcode: int, *args, **kwargs):
 def fake_login_token(mocker):
     mocker.patch("embedops_cli.embedops_cli._get_and_check_embedops_token", return_value="FakeToken")
 
-@pytest.mark.parametrize("err_code, exception", [(1,eo_types.DockerNotRunningException), (127,eo_types.NoDockerCLIException),(2, eo_types.UnknownDockerException)])
-def test_docker_not_found(mocker, err_code, exception, fake_login_token):
-    """Test docker command was not found"""
+def test_docker_not_found(monkeypatch, fake_login_token):
+    """Test docker command not found"""
+
+    # simulate docker CLI not found by setting PATH to an empty string
+    monkeypatch.setenv("PATH", "")
+
+    runner = CliRunner()
+    result = runner.invoke(embedops_cli.embedops_cli, "login")
+
+    exception = eo_types.NoDockerCLIException
+
+    assert result.exit_code == 1
+    assert exception.ERROR_MSG in result.output
+    assert exception.ERROR_FIX in result.output
+
+@pytest.mark.parametrize("err_code, exception", [(1,eo_types.DockerNotRunningException),(2, eo_types.UnknownDockerException)])
+def test_docker_not_running(mocker, err_code, exception, fake_login_token):
+    """Test docker command not running"""
+
+    # skip docker cli validation
+    mocker.patch("embedops_cli.docker_run.which")
+
     docker_status = mocker.patch("embedops_cli.docker_run.subprocess.run")
     docker_status.side_effect = lambda *args,**kwargs:subprocess_err_code(err_code,*args,**kwargs)
 
